@@ -7,7 +7,7 @@ foreach (1..10000) {
     eval { Exception::System->throw(message=>'Message') };
     if ($@) {
 	my $e = Exception::Base->catch;
-        if ($e->isa('Exception::Base') and $e->with('Message')) { 1; }
+        if ($e->isa('Exception::Base') and $e->matches('Message')) { 1; }
     }
 }
 
